DepthMode

Enum DepthMode 

#[repr(u32)]
pub enum DepthMode { Off = 0, NFov2x2Binned = 1, NFovUnbinned = 2, WFov2x2Binned = 3, WFovUnbinned = 4, PassiveIr = 5, }

Variants



Off = 0



NFov2x2Binned = 1



NFovUnbinned = 2



WFov2x2Binned = 3



WFovUnbinned = 4



PassiveIr = 5

Implementations

Source

impl DepthMode

pub fn get_dimension(&self) -> Dimension

Gets the dimensions of the depth images that the depth camera will produce for a given depth mode

pub fn get_range(&self) -> Range<u16>

Gets the range of values that we expect to see from the depth camera when using a given depth mode, in millimeters

pub fn get_ir_level(&self) -> Range<u16>

Gets the expected min/max IR brightness levels that we expect to see from the IR camera when using a given depth mode