Playback

Struct Playback 

pub struct Playback<'a> { /* private fields */ }

Implementations

Source

impl<'a> Playback<'a>

pub fn get_raw_calibration(&self) -> Result<Vec<u8>, Error>

Get the raw calibration blob for the K4A device that made the recording.

pub fn get_calibration(&self) -> Result<Calibration<'_>, Error>

Get the camera calibration for the K4A device that made the recording, which is used for all transformation

pub fn get_record_configuration(&self) -> Result<RecordConfiguration, Error>

Gets the configuration of the recording

pub fn get_next_capture(&self) -> Result<Capture<'_>, Error>

Get the next capture in the recording.

pub fn get_previous_capture(&self) -> Result<Capture<'_>, Error>

Get the previous capture in the recording.

pub fn get_tag(&self, name: &str) -> Result<String, Error>

Reads the value of a tag from the recording

pub fn get_next_imu_sample(&self) -> Result<ImuSample, Error>

Get the next IMU sample in the recording.

pub fn get_previous_imu_sample(&self) -> Result<ImuSample, Error>

Get the previous IMU sample in the recording.

pub fn seek_timestamp( &self, offset_usec: i64, origin: k4a_playback_seek_origin_t, ) -> Result<(), Error>

Seeks to a specific time point in the recording

pub fn get_recording_length_usec(&self) -> u64

Get the last valid timestamp in the recording

pub fn set_color_conversion(&mut self, format: ImageFormat) -> Result<(), Error>

Set the image format that color captures will be converted to. By default the conversion format will be the same as the image format stored in the recording file, and no conversion will occur.

pub fn get_next_data_block( &self, track: &str, ) -> Result<PlaybackDataBlock<'_>, Error>

Get the next data block in the recording.

pub fn get_previous_data_block( &self, track: &str, ) -> Result<PlaybackDataBlock<'_>, Error>

Get the previous data block from the recording.

pub fn get_attachment(&self, attachment: &str) -> Result<Vec<u8>, Error>

Get the attachment block from the recording.

pub fn get_track_count(&self) -> usize

Get the number of tracks in a playback file.

pub fn get_track(&self, track_index: usize) -> Result<PlaybackTrack<'_>, Error>

Gets the track at a specific index.